Module system

Module system 

Constants for system ioctls.

Structs

KvmSystem
The device type marker for the main KVM file descriptor, typically obtained by opening /dev/kvm.

Constants

KVM_CHECK_EXTENSION
Query whether the KVM subsystem in the current kernel supports a particular extension.
KVM_CREATE_VM
Create a new virtual machine and obtain the file that represents it.
KVM_GET_API_VERSION
Identifies the version of the KVM API used by the current kernel.
KVM_GET_VCPU_MMAP_SIZE
Returns the size of the shared memory region that will be used to communicate with userspace for each VCPU.