Module raw

Module raw 

Raw data types for use with various KVM ioctl requests.

Structs

ExitDebug
ExitException
ExitFailEntry
ExitIo
ExitMemoryFault
ExitMmio
ExitNotify
ExitRiscvCsr
ExitRiscvSbi
ExitSystemEvent
ExitUnknown
kvm_debug_exit_arch
kvm_one_reg
kvm_regs
kvm_run
The layout of the shared memory region used to communicate with the KVM_RUN ioctl request, which is mmaped from the VCPU’s file descriptor.
kvm_userspace_memory_region

Unions

ExitDetails
Used for the exit_details field of kvm_run.